@@ -338,17 +338,17 @@ saCkptDispatch (
 			error = CS_OK;
 			goto error_put;
 		}
-		if (error != CS_OK) {
-			goto error_put;
-		}
-
-		if (dispatch_data == NULL) {
+		if (error == CS_ERR_TRY_AGAIN) {
+			error = CS_OK;
 			if (dispatchFlags == CPG_DISPATCH_ALL) {
 				break; /* exit do while cont is 1 loop */
 			} else {
 				continue; /* next poll */
 			}
 		}
+		if (error != CS_OK) {
+			goto error_put;
+		}
 
 		/*
 		* Make copy of callbacks, message data, unlock instance,
@@ -574,6 +574,9 @@ saCkptCheckpointOpen (
 		&res_lib_ckpt_checkpointopen,
 		sizeof (struct res_lib_ckpt_checkpointopen));
 
+	if (error != SA_AIS_OK) {
+		goto error_put_destroy;
+	}
 	if (res_lib_ckpt_checkpointopen.header.error != SA_AIS_OK) {
 		error = res_lib_ckpt_checkpointopen.header.error;
 		goto error_put_destroy;
